library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all ;
use IEEE.numeric_std.all ;
Library UNISIM;
use UNISIM.vcomponents.all;

entity ENCODER1 is 
PORT (
        clk     : in std_logic; --Double Rate Clock line
        nRST    : in std_logic; --RESET line
        data_l  : in std_logic;
        data_r  : in std_logic;
        out_l   : out std_logic;
        out_r   : out std_logic
      );
 end entity ENCODER1;


architecture rtl of ENCODER1 is 
    signal d0_L        : std_logic;     --data reg left
    --signal d1_L        : std_logic;     --data reg inv left
    signal d0_R        : std_logic;     --data reg RIGHT
    --signal d1_R        : std_logic;     --data reg inv RIGHT
    signal y_reg, y_next: std_logic;    --internal wiring of the D-FF
    --signal R           : std_logic;     --R for active high reset from active low
    
begin
--assign inputs

    
process (nRST, clk, y_reg)        --positive edge detect
begin
 if nRST = '0' then
    d0_L   <= '0';
    d0_R   <= '0';
    y_reg  <= '0';
    elsif (rising_edge(clk)) then
    y_reg <= y_next;
    
    if y_reg = '0' then
        d0_L  <= data_l;
        d0_R  <= data_r;
    elsif y_reg = '1' then
        d0_L  <= not (data_L);
        d0_R  <= not (data_R);
    end if;
 end if;    
end process;

-- create the not feedback:
    y_next <= not y_reg;


-- Generate outputs
    out_L <= d0_L ;
    out_R <= d0_R ; 
 
end architecture rtl;